@@ -15,7 +15,7 @@ from office.lib.conf.CONST import SPLIT_LINE
 print(SPLIT_LINE)
 print('【python-office库】，功能持续更新中')
 print('使用有问题 or 提交你的功能需求 or 参与项目开发')
-print('1、给小白的【50讲Python自动化办公】：https://mp.weixin.qq.com/s/W39OFo6XoXsS-hL9poHP6Q')
+print('1、给小白的【50讲Python自动化办公】：https://mp.weixin.qq.com/s/6hAgvbcXhdWOh4K9OH73cA')
 print('2、请+【项目交流群】：http://t.cn/A65MiFvH')
 print('3、本开源项目的【源代码】：https://github.com/CoderWanFeng/python-office')
 print(SPLIT_LINE)
