@@ -8,8 +8,8 @@ from office.lib.decorator_utils.instruction_url import instruction
 
 # @except_dec()
 @instruction
-def transtools(to_lang: str, content: str):
-    wftools.transtools(to_lang, content)
+def transtools(to_lang: str, content: str, from_lang:str='zh'):
+    return wftools.transtools(to_lang=to_lang, content=content, from_lang=from_lang)
 
 
 # @except_dec()
